from setuptools import setup, find_packages

setup(
    name="FireMover",
    version="0.0.1",
    packages=find_packages(),
    install_requires=[],
    author="Muhammad Saboor Islam",
    author_email="muhammadsaboor119@gmail.com",
    description="This is a test package to reserve the name",
    long_description="This package is uploaded for name reservation only.",
    long_description_content_type="text/markdown",
    url="https://github.com/Muhammad Saboor Islam/FireMover",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
